@@ -746,7 +746,7 @@ plot_expirest_wisle <- function(
   model, rl_index = 1, show_grouping = "yes", response_vbl_unit = NULL,
   y_range, x_range = NULL, scenario = "standard", plot_option = "full",
   ci_app = "line") {
-  if (class(model) != "expirest_wisle") {
+  if (!inherits(model, "expirest_wisle")) {
     stop("The model must be an object of class expirest_wisle.")
   }
   if (!is.numeric(rl_index) | length(rl_index) > 1) {
@@ -979,8 +979,16 @@ plot_expirest_wisle <- function(
   colnames(d_new) <- c(batch_vbl, time_vbl)
 
   # Prediction
-  m_pred <- predict(model, newdata = d_new, interval = ivl,
-                    level = 1 - alpha)
+  if (model_name != "dids") {
+    m_pred <- predict(model, newdata = d_new, interval = ivl,
+                      level = 1 - alpha)
+  } else {
+    l_pred <- lapply(t_batches, function(x)
+      predict(l_models$individual[[x]],
+              newdata = d_new[d_new[, batch_vbl] == x, ],
+              interval = ivl, level = 1 - alpha))
+    m_pred <- do.call(rbind, l_pred)
+  }
 
   # Back-transformation of predicted (response) values, if necessary
   switch(xform[2],
